EnsCat:
This package includes several methods that can be used to cluster categorical data.
Description
EnsCat implements several methods for clustering of categorical data.Details
|
Package: |
| EnsCat |
|
Type: |
| Package |
|
Version: |
| 1.1 |
|
Date: |
| 2017-01-29 |
|
License: |
| >=GPL-2 |
References
Amiri, S., Clarke, B., and Clarke, J. (2015). Clustering categorical data via ensembling dissimilarity matrices. arXiv preprint arXiv:1506.07930.